==> hs-dataenc-0.14.0.5.tbz: lib/ghc-7.4.2/cabal/dataenc-0.14.0.5/register.sh <==
#!/bin/sh
echo 'name: dataenc
version: 0.14.0.5
id: dataenc-0.14.0.5-17e36066f5c86a8ac52e5de1be4e7f90

license: BSD3
copyright: Magnus Therning, 2007-2012
maintainer: none
stability:
homepage: http://www.haskell.org/haskellwiki/Library/Data_encoding
package-url:
synopsis: Data encoding library
description: Data encoding library currently providing Base16, Base32,
             Base32Hex, Base64, Base64Url, Base85, Python string escaping,
             Quoted-Printable, URL encoding, uuencode, xxencode, and yEncoding.
category: Codec
author: Magnus Therning
exposed: True
exposed-modules: Codec.Binary.Base16 Codec.Binary.Base32
                 Codec.Binary.Base32Hex Codec.Binary.Base64 Codec.Binary.Base64Url
                 Codec.Binary.Base85 Codec.Binary.DataEncoding
                 Codec.Binary.PythonString Codec.Binary.QuotedPrintable
                 Codec.Binary.Url Codec.Binary.Uu Codec.Binary.Xx Codec.Binary.Yenc
hidden-modules: Codec.Binary.Util
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.2/cabal/dataenc-0.14.0.5
library-dirs: /usr/local/lib/ghc-7.4.2/cabal/dataenc-0.14.0.5
              /usr/local/lib
hs-libraries: HSdataenc-0.14.0.5
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: array-0.4.0.0-4f6c2a594155b0b953c1cf0f54040f61
         base-4.5.1.0-12fddc14a7babb909dd3843e453b5660
         containers-0.4.2.1-efa59805336a77490296ae3897cecb87
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.2/cabal/dataenc-0.14.0.5/html/dataenc.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.2/cabal/dataenc-0.14.0.5/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-dataenc-0.14_1.tbz: lib/ghc-7.0.3/cabal/dataenc-0.14/register.sh <==
#!/bin/sh
echo 'name: dataenc
version: 0.14
id: dataenc-0.14-d918c7154531bbc36fff93f2b962b39a

license: BSD3
copyright: Magnus Therning, 2007-2011
maintainer: magnus@therning.org
stability:
homepage: http://www.haskell.org/haskellwiki/Library/Data_encoding
package-url:
description: Data encoding library currently providing Base16, Base32,
             Base32Hex, Base64, Base64Url, Base85, Python string escaping,
             Quoted-Printable, URL encoding, uuencode, xxencode, and yEncoding.
category: Codec
author: Magnus Therning
exposed: True
exposed-modules: Codec.Binary.Base16 Codec.Binary.Base32
                 Codec.Binary.Base32Hex Codec.Binary.Base64 Codec.Binary.Base64Url
                 Codec.Binary.Base85 Codec.Binary.DataEncoding
                 Codec.Binary.PythonString Codec.Binary.QuotedPrintable
                 Codec.Binary.Url Codec.Binary.Uu Codec.Binary.Xx Codec.Binary.Yenc
hidden-modules: Codec.Binary.Util
import-dirs: /usr/local/lib/ghc-7.0.3/cabal/dataenc-0.14
library-dirs: /usr/local/lib/ghc-7.0.3/cabal/dataenc-0.14
              /usr/local/lib
hs-libraries: HSdataenc-0.14
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: array-0.3.0.2-3444ee049e55c8df31a0796287f56a5e
         base-4.3.1.0-63fd52d9e7e39016c91be0baf3543757
         containers-0.4.0.0-8781485edb2ac0db733a9f9c72e27945
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.3/cabal/dataenc-0.14/html/dataenc.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.3/cabal/dataenc-0.14/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
